@@ -10,56 +10,66 @@ import scipy.integrate
 from . import *
 
 @beartype
-def Groma(
+def GUW(
     d: Scalar,
     r: Scalar,
-    c: dict,
+    o: dict,
     j: int,
     l: ScalarList,
 ) -> ScalarList:
     """
-    Return the Fourier amplitudes calculated with the Groma model.
+    Return the Fourier amplitudes calculated with the model GUW.
+
+    "GUW" means "Groma Ungár Wilkens". The model is described in:
+    I. Groma, T. Ungár, and M. Wilkens. “Asymmetric X-ray line
+    broadening of plastically deformed crystals. I. Theory”. In:
+    Journal of Applied Crystallography (1988). ISSN: 0021-8898.
 
     Input:
         d: density of dislocations [nm^-2]
         r: outer cut-off radius [nm]
-        c: common quantities dictionary
+        o: output data dictionary
         j: selected harmonic
         l: Fourier variable [nm]
 
     Output:
         a: Fourier amplitudes
     """
-    i = c['index'][j]
-    jgb, jg2, b2, C = c['jgb'][i], c['jg2'][i], c['b2'], c['C']
+    i = o['index'][j] # index of the harmonic in c
+    jgb, jg2, b2, C = o['jgb'][i], o['jg2'][i], o['b2'], o['C']
     k = np.pi/2*jg2*b2*C*d
     D = k * (np.log(l)-np.log(jgb*r))
     return np.exp(l**2*D)
 
 @beartype
-def Kamminga(
+def WS(
     d: Scalar,
     r: Scalar,
-    c: dict,
+    o: dict,
     j: int,
     l: ScalarList,
 ) -> ScalarList:
     """
-    Return the Fourier amplitudes calculated with the Kamminga model.
+    Return the Fourier amplitudes calculated with the model WS.
+
+    "WS" means "Wilkens simplified". The model is described in:
+    J.-D. Kamminga and R. Delhez. “Calculation of diffraction line
+    profiles for structures with dislocations”. In: Materials Science
+    Forum (2001). ISSN: 1662-9752.
 
     Input:
         d: density of dislocations [nm^-2]
         r: outer cut-off radius [nm]
-        c: common quantities dictionary
+        o: output data dictionary
         j: selected harmonic
         l: Fourier variable [nm]
 
     Output:
         a: Fourier amplitudes
     """
-    i = c['index'][j]
-    jgb, jg2, b2, C = c['jgb'][i], c['jg2'][i], c['b2'], c['C']
-    z, g = c['z'], c['g']
+    i = o['index'][j] # index of the harmonic in c
+    jgb, jg2, b2, C = o['jgb'][i], o['jg2'][i], o['b2'], o['C']
+    z, g = o['z'], o['g']
     nz, ng = np.linalg.norm(z), np.linalg.norm(g)
     s = np.sqrt(1-(np.dot(z, g)/(nz*ng))**2)
     k = np.pi/2*jg2*b2*C*d
@@ -71,13 +81,13 @@ def f(
     e: Scalar,
 ) -> Scalar:
     """
-    Intermediary function in the calculation of the Wilkens model.
+    Intermediary function in the calculation of the model WC.
 
     Input:
         e: value of Fourier variable divided by the outer cut-off radius [1]
 
     Output:
-        r: value of f on eta
+        r: value of f on e
     """
     e2 = e**2
     def h(v):
@@ -90,34 +100,39 @@ def f(
             - 1/np.pi*(769/180/e+41*e/90+2*e2*e/90)*(1-e2)**(1/2)
             - 1/np.pi*(11/12/e2+7/2+e2/3)*np.arcsin(e) + e2/6)
     else:
-        r = 512/90/pi/eta - (11/24+np.log(2)*eta/4)/eta2
+        r = 512/90/np.pi/e - (11/24+np.log(2)*e/4)/e2
     return r
 
 vf = np.vectorize(f)
 
 @beartype
-def Wilkens(
+def WC(
     d: Scalar,
     r: Scalar,
-    c: dict,
+    o: dict,
     j: int,
     l: ScalarList,
 ) -> ScalarList:
     """
-    Return the Fourier amplitudes calculated with the Kamminga model.
+    Return the Fourier amplitudes calculated with the model WC.
+
+    "WC" means "Wilkens complete". The model is described in:
+    M. Wilkens. Fundamental aspects of dislocation theory. Ed. by J. A.
+    Simmons, R. de Wit, and R. Bullough. Vol. 2. U.S. National Bureau
+    of Standards, 1970, pp. 1195–1221.
 
     Input:
         d: density of dislocations [nm^-2]
         r: outer cut-off radius [nm]
-        c: common quantities dictionary
+        o: output data dictionary
         j: selected harmonic
         l: Fourier variable [nm]
 
     Output:
         a: Fourier amplitudes
     """
-    i = c['index'][j]
-    jg2, b2, C = c['jg2'][i], c['b2'], c['C']
+    i = o['index'][j] # index of the harmonic in c
+    jg2, b2, C = o['jg2'][i], o['b2'], o['C']
     k = np.pi/2*jg2*b2*C*d
     D = -k * vf(np.exp(1/4)*l/2/r)
     AD = np.exp(l**2*D)
